@@ -4,7 +4,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.001002';
+our $VERSION = '0.001003';
 
 1;
 
@@ -20,7 +20,7 @@ WebService::MinFraud - BETA Perl API for MaxMind's minFraud Score and Insights w
 
 =head1 VERSION
 
-version 0.001002
+version 0.001003
 
 =head1 SYNOPSIS
 
@@ -94,12 +94,22 @@ client API please visit L<http://www.maxmind.com/en/support> for details.
 
 Mateu Hunter <mhunter@maxmind.com>
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
 
-=for stopwords Andy Jack
+=for stopwords Andy Jack Greg Oschwald
+
+=over 4
+
+=item *
 
 Andy Jack <ajack@maxmind.com>
 
+=item *
+
+Greg Oschwald <goschwald@maxmind.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015 by MaxMind, Inc..
