@@ -3,14 +3,17 @@ package WebService::MinFraud::Client;
 use 5.010;
 use Moo 1.004005;
 
-our $VERSION = '0.001002';
+our $VERSION = '0.001003';
 
+use HTTP::Headers ();
+use HTTP::Request ();
 use JSON::MaybeXS;
 use LWP::UserAgent;
 use Scalar::Util qw( blessed );
 use Sub::Quote qw( quote_sub );
 use Try::Tiny;
 use Types::Standard qw( InstanceOf );
+use URI ();
 use WebService::MinFraud::Error::Generic;
 use WebService::MinFraud::Error::HTTP;
 use WebService::MinFraud::Error::IPAddressNotFound;
@@ -41,7 +44,7 @@ has _json => (
     is       => 'ro',
     isa      => JSONObject,
     init_arg => undef,
-    default  => quote_sub(q{ JSON->new->utf8 }),
+    default  => quote_sub(q{ JSON()->new->utf8 }),
 );
 has license_key => (
     is       => 'ro',
@@ -77,6 +80,7 @@ has _validator => (
     is      => 'lazy',
     isa     => InstanceOf ['WebService::MinFraud::Validator'],
     builder => sub { WebService::MinFraud::Validator->new },
+    handles => { _remove_trivial_hash_values => '_delete' },
 );
 
 sub BUILD {
@@ -118,6 +122,8 @@ sub score {
 sub _response_for {
     my ( $self, $path, $model_class, $content ) = @_;
 
+    $content = $self->_remove_trivial_hash_values($content);
+    $self->_fix_booleans($content);
     $self->_validator->validate_request($content);
     my $uri = $self->_base_uri->clone;
     $uri->path_segments( $uri->path_segments, $path );
@@ -144,6 +150,31 @@ sub _response_for {
     }
 }
 
+{
+    my @Booleans = (
+        [ 'order',   'is_gift' ],
+        [ 'order',   'has_gift_message' ],
+        [ 'payment', 'was_authorized' ],
+    );
+
+    sub _fix_booleans {
+        my $self    = shift;
+        my $content = shift;
+
+        return unless $content;
+
+        for my $boolean (@Booleans) {
+            my ( $object, $key ) = @{$boolean};
+            next unless exists $content->{$object}{$key};
+
+            $content->{$object}{$key}
+                = $content->{$object}{$key}
+                ? JSON()->true
+                : JSON()->false;
+        }
+    }
+}
+
 sub _handle_success {
     my $self     = shift;
     my $response = shift;
@@ -288,7 +319,7 @@ WebService::MinFraud::Client - Perl API for MaxMind's minFraud Score and Insight
 
 =head1 VERSION
 
-version 0.001002
+version 0.001003
 
 =head1 SYNOPSIS
 
@@ -461,22 +492,13 @@ The request methods are passed a HashRef as the only argument. See the L</SYNOPS
 This must be a valid IPv4 or IPv6 address in presentation format, i.e.,
 dotted-quad notation or the IPv6 hexadecimal-colon notation.
 
-=head2 payment => was_authorized
-
-The optional
-L<Payment|https://dev.maxmind.com/minfraud/minfraud-score-and-insights-api-documentation/#Payment_payment>
-top-level field has a C<< was_authorized >> key. The minFraud web service
-expects a JSON boolean type which is distinct from values that Perl treats as
-true or false.  We recommend using C<< 0 >> for false, C<< 1 >> for true, and
-C<< undef >> for unknown, when setting the value for C<< was_authorized >> in
-the request.  Other values may fail local validation or be rejected as invalid
-by the minFraud web service.
-
 =head1 REQUEST METHODS
 
 All of the request methods require a device ip_address. See the
 L<API documentation|https://dev.maxmind.com/minfraud/minfraud-score-and-insights-api-documentation/>
-for details on all the values that can be part of the request.
+for details on all the values that can be part of the request.  Portions of the
+request hash with undefined and empty string values are automatically removed
+from the request.
 
 =head2 score
 
