@@ -2,8 +2,9 @@ package WebService::MinFraud::Validator;
 
 use Moo;
 
-our $VERSION = '0.001002';
+our $VERSION = '0.001003';
 
+use Data::Delete 0.05;
 use Data::Rx;
 use Try::Tiny;
 use Types::Standard qw( HashRef InstanceOf Object );
@@ -14,6 +15,13 @@ use WebService::MinFraud::Data::Rx::Type::Hostname;
 use WebService::MinFraud::Data::Rx::Type::IPAddress;
 use WebService::MinFraud::Data::Rx::Type::WebURI;
 
+has _deleter => (
+    is      => 'lazy',
+    isa     => InstanceOf ['Data::Delete'],
+    builder => sub { Data::Delete->new },
+    handles => { _delete => 'delete' },
+);
+
 has _request_schema_definition => (
     is      => 'lazy',
     isa     => HashRef,
@@ -158,10 +166,12 @@ sub _build_request_schema_definition {
                         type   => '//str',
                         length => { 'min' => 3, 'max' => 3 },
                     },
-                    discount_code   => '//str',
-                    affiliate_id    => '//str',
-                    subaffiliate_id => '//str',
-                    referrer_uri    => '/maxmind/weburi',
+                    discount_code    => '//str',
+                    affiliate_id     => '//str',
+                    subaffiliate_id  => '//str',
+                    referrer_uri     => '/maxmind/weburi',
+                    is_gift          => '//bool',
+                    has_gift_message => '//bool',
                 },
             },
             payment => {
@@ -242,11 +252,8 @@ sub _build_request_schema_definition {
 
                         },
                     },
-                    was_authorized => {
-                        type => '//any',
-                        of   => [ '//nil', '//bool', '//int' ]
-                    },
-                    decline_code => '//str',
+                    was_authorized => '//bool',
+                    decline_code   => '//str',
                 },
             },
             shipping => {
@@ -306,9 +313,12 @@ sub validate_request {
         $self->_schema->assert_valid($request);
     }
     catch {
-        my @error_strings
-            = map { 'VALUE: ' . $_->value . ' caused ERROR: ' . $_->stringify }
-            @{ $_->failures };
+        my @error_strings = map {
+                  'VALUE: '
+                . ( defined $_->value ? $_->value : 'undef' )
+                . ' caused ERROR: '
+                . $_->stringify
+        } @{ $_->failures };
         my $all_error_strings = join "\n", @error_strings;
         die $all_error_strings;
     };
@@ -328,7 +338,7 @@ WebService::MinFraud::Validator - Validation for the minFraud requests
 
 =head1 VERSION
 
-version 0.001002
+version 0.001003
 
 =head1 SYNOPSIS
 
